'use strict';

const snekfetch = require('snekfetch');
const store = require('./store');

const Module = {

  async filters(type, url) {
    return new Promise(async(resolve, reject) => {
      if (!store.filters.includes(type)) return reject(`[Arcadia] Error, no valid type\n[Type] Filters valid:\n${store.filters.map(f => f)}`);
      if (!url) return reject('[Arcadia] Error, no link specified');
      try {
        await snekfetch.get(`https://www.arcadia-api.xyz/api/v1/${type}?url=${url}`).then(res => {
          if (res.error) reject(res.error);
          resolve(res.body)
        }).catch(err => {
          return reject(err);
        });
      } catch (e) {
        return reject(err.message)
      };
    });
  },

  async generation(type, url, options) {
    return new Promise(async(resolve, reject) => {
      let opts;
      if (!store.gens.includes(type)) return reject(`[Arcadia] Error, no valid type\n[Type] Generation valid:\n${store.gens.map(f => f)}`);
      if (!url) return reject('[Arcadia] Error, no link specified');
      if (!options) {
        opts = ''
      } else if (![0, 1].includes(options)) {
        return reject('[Arcadia] Error, options invalid\n[Options] Options valid: 0 or 1')
      } else {
        opts = `&type=${options}`
      }
      try {
        await snekfetch.get(`https://www.arcadia-api.xyz/api/v1/${type}?url=${url}${opts}`).then(res => {
          if (res.error) reject(res.error);
          resolve(res.body)
        }).catch(err => {
          return reject(err);
        });
      } catch (e) {
        return reject(err.message)
      };
    });
  },

  async texts(type, query) {
    return new Promise(async(resolve, reject) => {
      if (!store.texts.includes(type)) return reject(`[Arcadia] Error, no valid type\n[Type] Texts valid:\n${store.texts.map(f => f)}`);
      if (!query) return reject('[Arcadia] Error, no text specified');
      if (!query.length > 219) return reject('[Arcadia] Error, 219 characters maximum');
      try {
        await snekfetch.get(`https://www.arcadia-api.xyz/api/v1/${type}?text=${query}`).then(res => {
          if (res.error) reject(res.error);
          resolve(res.body)
        }).catch(err => {
          return reject(err);
        });
      } catch (e) {
        return reject(err.message)
      };
    });
  }

}
module.exports = Module;
